v0.0.4 (December, 1st 2025)
===========================

Known issues
^^^^^^^^^^^^^^^^^^^^

* Simulation tests do not test, as check_if_csv_files_equal
  from helpers module is incomplete.


Other changes
^^^^^^^^^^^^^^^^^^^^

* Made compatible with oemof.solph v0.6


Contributors
^^^^^^^^^^^^^^^^^^^^

* Patrik Schönfeldt (DLR)
